@@ -17,6 +17,7 @@ from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
+from .literals import TargetStoreType
 from .type_defs import (
     BatchGetRecordIdentifierTypeDef,
     BatchGetRecordResponseTypeDef,
@@ -89,7 +90,12 @@ class SageMakerFeatureStoreRuntimeClient(BaseClient):
         """
 
     def delete_record(
-        self, *, FeatureGroupName: str, RecordIdentifierValueAsString: str, EventTime: str
+        self,
+        *,
+        FeatureGroupName: str,
+        RecordIdentifierValueAsString: str,
+        EventTime: str,
+        TargetStores: Sequence[TargetStoreType] = ...
     ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a `Record` from a `FeatureGroup`.
@@ -127,7 +133,11 @@ class SageMakerFeatureStoreRuntimeClient(BaseClient):
         """
 
     def put_record(
-        self, *, FeatureGroupName: str, Record: Sequence[FeatureValueTypeDef]
+        self,
+        *,
+        FeatureGroupName: str,
+        Record: Sequence[FeatureValueTypeDef],
+        TargetStores: Sequence[TargetStoreType] = ...
     ) -> EmptyResponseMetadataTypeDef:
         """
         Used for data ingestion into the `FeatureStore`.
